==> 3.5.12-core.tar: kdepim/certmanager/lib/backends/qgpgme/qgpgmekeygenerationjob.h <==
/*
    qgpgmekeygenerationjob.h

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2004 Klarlvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEO_QGPGMEKEYGENERATIONJOB_H__
#define __KLEO_QGPGMEKEYGENERATIONJOB_H__

#include <kleo/keygenerationjob.h>

#include "qgpgmejob.h"
#include <kdepimmacros.h>

namespace GpgME {
  class Error;
  class Context;
  class Key;
  class Data;
}

namespace QGpgME {
  class QByteArrayDataProvider;
}

namespace Kleo {

  class KDE_EXPORT QGpgMEKeyGenerationJob : public KeyGenerationJob, private QGpgMEJob {
    Q_OBJECT QGPGME_JOB
  public:
    QGpgMEKeyGenerationJob( GpgME::Context * context );
    ~QGpgMEKeyGenerationJob();
    
    /*! \reimp from KeygenerationJob */
    GpgME::Error start( const TQString & parameters );
    
  private slots:
    void slotOperationDoneEvent( GpgME::Context * context, const GpgME::Error & error ) {
      QGpgMEJob::doSlotOperationDoneEvent( context, error );
    }

  private:
    void doOperationDoneEvent( const GpgME::Error & e );

  private:
    QGpgME::QByteArrayDataProvider * mPubKeyDataProvider;
    GpgME::Data * mPubKey;
  };

}

#endif // __KLEO_QGPGMEKEYGENERATIONJOB_H__

==> 3.5.13-core.tar: kdepim/certmanager/lib/backends/qgpgme/qgpgmekeygenerationjob.h <==
/*
    qgpgmekeygenerationjob.h

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2004 Klarlvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the TQt library by Trolltech AS, Norway (or with modified versions
    of TQt that use the same license as TQt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    TQt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEO_TQGPGMEKEYGENERATIONJOB_H__
#define __KLEO_TQGPGMEKEYGENERATIONJOB_H__

#include <kleo/keygenerationjob.h>

#include "qgpgmejob.h"
#include <kdepimmacros.h>

namespace GpgME {
  class Error;
  class Context;
  class Key;
  class Data;
}

namespace QGpgME {
  class TQByteArrayDataProvider;
}

namespace Kleo {

  class KDE_EXPORT QGpgMEKeyGenerationJob : public KeyGenerationJob, private QGpgMEJob {
    Q_OBJECT
    TQ_OBJECT TQGPGME_JOB
  public:
    QGpgMEKeyGenerationJob( GpgME::Context * context );
    ~QGpgMEKeyGenerationJob();
    
    /*! \reimp from KeygenerationJob */
    GpgME::Error start( const TQString & parameters );
    
  private slots:
    void slotOperationDoneEvent( GpgME::Context * context, const GpgME::Error & error ) {
      QGpgMEJob::doSlotOperationDoneEvent( context, error );
    }

  private:
    void doOperationDoneEvent( const GpgME::Error & e );

  private:
    QGpgME::TQByteArrayDataProvider * mPubKeyDataProvider;
    GpgME::Data * mPubKey;
  };

}

#endif // __KLEO_TQGPGMEKEYGENERATIONJOB_H__
